Installation
============

Source code
-----------

A gzipped tar archive of the source code for each release is available for download on the `Release page`_ on GitHub,
along with its GPG signature. The source code repository is available from `Wikimedia's Gerrit`_ website and mirrored
on `GitHub`_. To install it, from the ``master`` branch run:

.. code-block:: none

    python setup.py install

.. _`Wikimedia's Gerrit`: https://gerrit.wikimedia.org/r/admin/projects/operations/software/wmflib
.. _`GitHub`: https://github.com/wikimedia/operations-software-wmflib
.. _`Release page`: https://github.com/wikimedia/operations-software-wmflib/releases